@@ -29,7 +29,7 @@
 #include <gtkmm/stock.h>
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/filechooserdialog.h>
-#include <libgnomevfsmm.h>
+#include <giomm.h>
 #include <libintl.h>
 
 
@@ -41,7 +41,7 @@ void GtkDialogs::ui_warning(App& app, const Glib::ustring& text, const Glib::ust
   Gtk::Window* pWindow = dynamic_cast<Gtk::Window*>(&app);
 
 #ifdef BAKERY_MAEMO_ENABLED
-  Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, text, Gtk::Stock::DIALOG_WARNING);
+  Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, text, Gtk::Stock::DIALOG_WARNING));
 #else
   Gtk::MessageDialog dialog(App_Gtk::util_bold_message(text), true /* use markup */, Gtk::MESSAGE_WARNING);
   dialog.set_secondary_text(secondary_text);
@@ -60,7 +60,7 @@ Glib::ustring GtkDialogs::ui_file_select_open(App& app, const Glib::ustring& sta
   Gtk::Window* pWindow = dynamic_cast<Gtk::Window*>(&app);
 
 #ifdef BAKERY_MAEMO_ENABLED
-  Hildon::FileChooserDialog fileChooser_Open(Gtk::FILE_CHOOSER_ACTION_OPEN);
+  Hildon::FileChooserDialog fileChooser_Open(Gtk::FILE_CHOOSER_ACTION_OPEN));
 #else
   Gtk::FileChooserDialog fileChooser_Open(gettext("Open Document"), Gtk::FILE_CHOOSER_ACTION_OPEN);
   fileChooser_Open.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
@@ -84,24 +84,35 @@ Glib::ustring GtkDialogs::ui_file_select_open(App& app, const Glib::ustring& sta
     return Glib::ustring();
 }
 
-static bool uri_is_writable(const Glib::RefPtr<const Gnome::Vfs::Uri>& uri)
+static bool uri_is_writable(const Glib::RefPtr<const Gio::File>& uri)
 {
   if(!uri)
     return false;
 
+  Glib::RefPtr<const Gio::FileInfo> file_info;
+
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
-  Glib::RefPtr<const Gnome::Vfs::FileInfo> file_info = uri->get_file_info(Gnome::Vfs::FILE_INFO_GET_ACCESS_RIGHTS);
+  try
+  {
+    file_info = uri->query_info(G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE);
+  }
+  catch(const Glib::Error& /* ex */)
+  {
+    return false;
+  }
 #else
-  std::auto_ptr<Gnome::Vfs::exception> error;
-  Glib::RefPtr<const Gnome::Vfs::FileInfo> file_info = uri->get_file_info(Gnome::Vfs::FILE_INFO_GET_ACCESS_RIGHTS, error);
+  std::auto_ptr<Gio::Error> error;
+  file_info = uri->query_info(G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE, Gio::FILE_QUERY_INFO_NONE, error);
+  if(error.get())
+    return false;
 #endif
+
   if(file_info)
   {
-    const Gnome::Vfs::FilePermissions permissions = file_info->get_permissions();
-    return ((permissions & Gnome::Vfs::PERM_ACCESS_WRITABLE) == Gnome::Vfs::PERM_ACCESS_WRITABLE);
+    return file_info->get_attribute_boolean(G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE);
   }
   else
-    return true; //Not every URI protocol supports FILE_INFO_GET_ACCESS_RIGHTS, so assume that it's writable and complain later.
+    return true; //Not every URI protocol supports access rights, so assume that it's writable and complain later.
 }
 
 Glib::ustring GtkDialogs::ui_file_select_save(App& app, const Glib::ustring& old_file_uri)
@@ -127,11 +138,15 @@ Glib::ustring GtkDialogs::ui_file_select_save(App& app, const Glib::ustring& old
   {
     //Just start with the parent folder,
     //instead of the whole name, to avoid overwriting:
-    Glib::RefPtr<Gnome::Vfs::Uri> vfs_uri = Gnome::Vfs::Uri::create(old_file_uri);
-    if(vfs_uri)
+    Glib::RefPtr<Gio::File> gio_file = Gio::File::create_for_uri(old_file_uri);
+    if(gio_file)
     {
-      Glib::ustring uri_parent = vfs_uri->extract_dirname();
-      fileChooser_Save.set_uri(uri_parent);
+      Glib::RefPtr<Gio::File> parent = gio_file->get_parent();
+      if(parent)
+      {
+        const Glib::ustring uri_parent = parent->get_uri();
+        fileChooser_Save.set_uri(uri_parent);
+      }
     }
   }
 
@@ -160,16 +175,14 @@ Glib::ustring GtkDialogs::ui_file_select_save(App& app, const Glib::ustring& old
     {
       const Glib::ustring uri = fileChooser_Save.get_uri();
 
-      Glib::RefPtr<Gnome::Vfs::Uri> vfs_uri = Gnome::Vfs::Uri::create(uri);
-      if(!vfs_uri)
-        return Glib::ustring(); //Failure.
+      Glib::RefPtr<Gio::File> gio_file = Gio::File::create_for_uri(uri);
 
       //If the file exists (the FileChooser offers a "replace?" dialog, so this is possible.):
       if(App_WithDoc::file_exists(uri))
       {
         //Check whether we have rights to the file to change it:
         //Really, GtkFileChooser should do this for us.
-        if(!uri_is_writable(vfs_uri))
+        if(!uri_is_writable(gio_file))
         {
            //Warn the user:
            ui_warning(app, gettext("Read-only File."), gettext("You may not overwrite the existing file, because you do not have sufficient access rights."));
@@ -180,10 +193,10 @@ Glib::ustring GtkDialogs::ui_file_select_save(App& app, const Glib::ustring& old
 
       //Check whether we have rights to the directory, to create a new file in it:
       //Really, GtkFileChooser should do this for us.
-      Glib::RefPtr<const Gnome::Vfs::Uri> vfs_uri_parent = vfs_uri->get_parent();
-      if(vfs_uri_parent)
+      Glib::RefPtr<const Gio::File> gio_file_parent = gio_file->get_parent();
+      if(gio_file_parent)
       {
-        if(!uri_is_writable(vfs_uri_parent))
+        if(!uri_is_writable(gio_file_parent))
         {
           //Warn the user:
            ui_warning(app, gettext("Read-only Directory."), gettext("You may not create a file in this directory, because you do not have sufficient access rights."));
