@@ -17,7 +17,7 @@
  */
 
 #include "bakery/Document/Document.h"
-#include <libgnomevfsmm.h>
+#include <giomm.h>
 //#include <fstream>
 #include <libintl.h>
 
@@ -190,29 +190,30 @@ bool Document::read_from_disk()
 {
   m_strContents.erase();
 
-  // open the input file for read access
-  Gnome::Vfs::Handle read_handle;
+  // Open the input file for read access:
+  Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(m_file_uri);
+  Glib::RefPtr<Gio::FileInputStream> stream;
 
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
-    read_handle.open(m_file_uri, Gnome::Vfs::OPEN_READ);
+    stream = file->read();
   }
-  catch(const Gnome::Vfs::exception& ex)
+  catch(const Gio::Error& ex)
   {
     // If the operation was not successful, print the error and abort
     return false; //print_error(ex, input_uri_string);
   }
 #else
-  std::auto_ptr<Gnome::Vfs::exception> error;
-  read_handle.open(m_file_uri, Gnome::Vfs::OPEN_READ, error);
+  std::auto_ptr<Gio::Error> error;
+  Glib::RefPtr<FileInputStream> stream = file.read(error);
   if(error.get() != NULL)
     return false; //print_error(ex, input_uri_string);
 #endif
 
   // Read data from the input uri:
   guint buffer[BYTES_TO_PROCESS] = {0, }; // For each chunk.
-  Gnome::Vfs::FileSize bytes_read = 0;
+  gsize bytes_read = 0;
   std::string data; //We use a std::string because we might not get whole UTF8 characters at a time. This might not be necessary.
 
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
@@ -223,9 +224,9 @@ bool Document::read_from_disk()
     while(bContinue)
     {
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
-      bytes_read = read_handle.read(buffer, BYTES_TO_PROCESS);
+      bytes_read = stream->read(buffer, BYTES_TO_PROCESS);
 #else
-      bytes_read = read_handle.read(buffer, BYTES_TO_PROCESS, error);
+      bytes_read = stream->read(buffer, BYTES_TO_PROCESS, error);
       if(error.get() != NULL) break;
 #endif
 
@@ -239,12 +240,12 @@ bool Document::read_from_disk()
     }
   }
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
-  catch(const Gnome::Vfs::exception& ex)
+  catch(const Gio::Error& ex)
   {
 #else
   if(error.get() != NULL)
   {
-    Gnome::Vfs::exception& ex = *error.get();
+    Gio::Error& ex = *error.get();
 #endif
     // If the operation was not successful, print the error and abort
     return false; //print_error(ex, input_uri_string);
@@ -262,45 +263,55 @@ bool Document::write_to_disk()
   //Write the changed data to disk:
   if(get_modified())
   {
-    /* we use create instead of open, because open will not create the file if it does
-    not already exist. The last argument is the permissions to use if the file is created,
-    the second to last tells GnomeVFS that its ok if the file already exists, and just open it */
-
-    Gnome::Vfs::Handle write_handle;
+    Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(m_file_uri);
+    Glib::RefPtr<Gio::FileOutputStream> stream;
 
+    //Create the file if it does not already exist:
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
     try
     {
-      //0660 means "this user and his group can read and write this non-executable file".
-      //The 0 prefix means that this is octal.
-      write_handle.create(m_file_uri, Gnome::Vfs::OPEN_WRITE, false, 0660 /* leading zero means octal */);
+      if(file->query_exists())
+      {
+        stream = file->replace(); //Instead of append_to().
+      }
+      else
+      {
+        //By default files created are generally readable by everyone, but if we pass FILE_CREATE_PRIVATE in flags the file will be made readable only to the current user, to the level that is supported on the target filesystem.
+        //TODO: Do we want to specify 0660 exactly? (means "this user and his group can read and write this non-executable file".)
+        stream = file->create_file();
+      }
     }
-    catch(const Gnome::Vfs::exception& ex)
+    catch(const Gio::Error& ex)
     {
 #else
-    std::auto_ptr<Gnome::Vfs::exception> error;
-    write_handle.create(m_file_uri, Gnome::Vfs::OPEN_WRITE, false, 0660 /* loading zero means octal */, error);
+    std::auto_ptr<Gio::Error> error;
+    stream.create(error);
     if(error.get() != NULL)
     {
-      const Gnome::Vfs::exception& ex = *error.get();
+      const Gio::Error& ex = *error.get();
 #endif
      // If the operation was not successful, print the error and abort
      return false; // print_error(ex, output_uri_string);
     }
 
+
+    if(!stream)
+      return false;
+
+
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
     try
     {
       //Write the data to the output uri
-      GnomeVFSFileSize bytes_written = write_handle.write(m_strContents.data(), m_strContents.bytes());
+      const gsize bytes_written = stream->write(m_strContents.data(), m_strContents.bytes());
     }
-    catch(const Gnome::Vfs::exception& ex)
+    catch(const Gio::Error& ex)
     {
 #else
-    GnomeVFSFileSize bytes_written = write_handle.write(m_strContents.data(), m_strContents.bytes(), error);
+    const gsize bytes_written = stream->write(m_strContents.data(), m_strContents.bytes(), error);
     if(error.get() != NULL)
     {
-      Gnome::Vfs::exception& ex = *error.get();
+      Gio::Error& ex = *error.get();
 #endif
       // If the operation was not successful, print the error and abort
       return false; //print_error(ex, output_uri_string);
@@ -359,7 +370,7 @@ bool Document::get_read_only() const
 {
   if(m_bReadOnly)
   {
-    //An application might have use set_read_only() to make this document explicitly read_only, regardless of the positions of the storage location.
+    //An application might have used set_read_only() to make this document explicitly read_only, regardless of the positions of the storage location.
     return true;
   }
   else
@@ -368,24 +379,28 @@ bool Document::get_read_only() const
       return false; //It must be a default empty document, not yet saved, so it is not read-only.
     else
     {
-      Glib::RefPtr<Gnome::Vfs::FileInfo> info;
+      Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(m_file_uri);
+      Glib::RefPtr<Gio::FileInfo> info;
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
       try
       {
-        info = Gnome::Vfs::Handle::get_file_info(m_file_uri, Gnome::Vfs::FILE_INFO_GET_ACCESS_RIGHTS);
+        Glib::RefPtr<Gio::FileInfo> info = file->query_info(G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE);
       }
-      catch(const Gnome::Vfs::exception& ex)
+      catch(const Gio::Error& ex)
       {
         return false; //We should at least be able to read the permissions, so maybe the location is invalid. I'm not sure what the best return result here is.
       }
 #else
-      std::auto_ptr<Gnome::Vfs::exception> error;
-      info = Gnome::Vfs::Handle::get_file_info(m_file_uri, Gnome::Vfs::FILE_INFO_GET_ACCESS_RIGHTS, error);
-      if(error.get() != NULL) return false;
+      std::auto_ptr<Gio::Error> error;
+      info = file.query_info(G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE, Gio::FILE_QUERY_INFO_NONE, error);
+      if(error.get() != NULL)
+        return false;
 #endif
 
-      Gnome::Vfs::FilePermissions permissions = info->get_permissions();
-      const bool read_only = ((permissions & Gnome::Vfs::PERM_ACCESS_WRITABLE) != Gnome::Vfs::PERM_ACCESS_WRITABLE);
+      if(!info)
+        return false;
+
+      const bool read_only = info->get_attribute_boolean(G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE);
       return read_only;
     }
   }
