@@ -49,8 +49,16 @@ public:
 
   /** Whether to add extra whitespace when writing the XML to disk.
    * Do not use this if whitespace is significant in your XML format.
+   * See also add_indenting_white_space().
    */
-  virtual void set_write_formatted(bool formatted = true);
+  void set_write_formatted(bool formatted = true);
+
+  /** Put each node on its own line and add white space for indenting,
+   * even if there are child text nodes.
+   * set_write_formatted() does not cause nodes to be indented if there are child text nodes,
+   * because it assumes that the white space is then significant.
+   */
+  void add_indenting_white_space();
   
   virtual bool set_xml(const Glib::ustring& strXML); //Parse the XML from the text.
   virtual Glib::ustring get_xml() const; //Get the text for the XML.
@@ -58,16 +66,17 @@ public:
 protected:
   static Glib::ustring get_node_attribute_value(const xmlpp::Element* node, const Glib::ustring& strAttributeName);
   static void set_node_attribute_value(xmlpp::Element* node, const Glib::ustring& strAttributeName, const Glib::ustring& strValue);
-  virtual xmlpp::Element* get_node_child_named(const xmlpp::Element* node, const Glib::ustring& strName);
-  virtual const xmlpp::Element* get_node_child_named(const xmlpp::Element* node, const Glib::ustring& strName) const;
-  virtual xmlpp::Element* get_node_child_named_with_add(xmlpp::Element* node, const Glib::ustring& strName);
+
+  static xmlpp::Element* get_node_child_named(const xmlpp::Element* node, const Glib::ustring& strName);
+  static xmlpp::Element* get_node_child_named_with_add(xmlpp::Element* node, const Glib::ustring& strName);
 
   virtual const xmlpp::Element* get_node_document() const; //e.g. <glom_document> (root name)
   virtual xmlpp::Element* get_node_document(); //e.g. <glom_document> (root name)
 
-
   virtual void Util_DOM_Write(Glib::ustring& refstrXML) const;
 
+  void add_indenting_white_space_to_node(xmlpp::Node* node = 0, const Glib::ustring& start_indent = Glib::ustring());
+
   typedef Bakery::Document type_base;
 
   //XML Parsing bits:
